
function getAppControlInterfaces() {
    var promise;
    if (navigator.userAgent.search("WSPlayer") != -1) {
        // Running on the video player
        promise = IDAL.getControlInterfaces();
    } else {
        // Fetch the demonstration settings file, returning a promise resolved
        // with the settings object.
        function getApplicationConfiguration() {
            return new Promise(function(resolve, reject) {
                var xhr = new XMLHttpRequest();

                xhr.addEventListener("readystatechange", function() {
                    if(this.readyState === 4) {
                        if (xhr.status === 200) {
                            try {
                                var response = JSON.parse(this.responseText);
                                if (!response.hostname) reject('Missing "hostname" property.');
                                else if (!response.username) reject('Missing "username" property.');
                                else if (!response.password) reject('Missing "password" property.');
                                else if (!response.hasOwnProperty('use-remote-player')) reject('Missing "use-remote-player" property.');
                                else resolve(response);
                            } catch(e) {
                                reject(e);
                            }
                        }
                        reject("Invalid HTTP response status " + xhr.status);
                    }
                });
                console.log("Getting demo-config.json (you can edit this file with your settings)...");
                xhr.open("GET", "../demo-config.json"); // URL path making the assertion that each example is in a subdirectory (level 1)
                xhr.send();
            });
        }

        // Running on an external browser, try to get the video player info...
        return getApplicationConfiguration()
            .then(function(config) {
                if (config["use-remote-player"]) {
                    console.log("Connecting to remote video player '" + config.hostname + "' with user '" + config.username + "' and password='" + config.password + "'");
                    return IDAL.getRemoteControlInterfaces(config.hostname, config.username, config.password);
                } else {
                    // Stubbed implementation
                    console.warn("Remote player control disabled, falling back to stubbed implementation (edit demo-config.json to change this behavior)");
                    return IDAL.getControlInterfaces();
                }
            })
            .catch(function(error) {
                var message;
                if (location.protocol == 'file:') {
                    message = "This page must served by an HTTP server!\nOpening this HTML file on the local filesystem cannot work at all!\nFalling back to stubbed implementation...";
                } else {
                    message = "Failed to get demo-config.json, falling back to stubbed implementation...\n" + error;
                }

                console.error(message);
                alert(message);
                return IDAL.getControlInterfaces();
            });
    }

    return promise;
}
