var gContactControlInterface;

var gOutputContacts, gCombinedInputContacts, gStandaloneInputContacts;

function createOutputContactCheckBox(parent, idx) {
    var div = document.createElement("div");

    var input = document.createElement("input");
    input.type = "checkbox";
    input.name = "output" + (idx + 1);
    input.onchange = function() {
        setOutputById(idx, input.checked);
    };

    var label = document.createElement("label");
    label.for = input.name;
    label.innerText = "Output " + (idx + 1);
    label.addEventListener("click", function() {
        input.checked = !input.checked;
        setOutputById(idx, input.checked);
    });

    div.appendChild(input);
    div.appendChild(label);
    parent.appendChild(div);

    return input;
}

function createInputContactCheckBox(parent, idx) {
    var div = document.createElement("div");

    var input = document.createElement("input");
    input.type = "checkbox";
    input.name = "input" + (idx + 1);
    input.onclick = function() {
        return false;
    }

    var label = document.createElement("label");
    label.for = input.name;
    label.innerText = "Input " + (idx + 1);

    div.appendChild(input);
    div.appendChild(label);
    parent.appendChild(div);

    return input;
}

function onPageLoaded() {
    gConsole = new OnScreenConsole();
    gConsole.initialize("console")

    gOutputContacts = initOutputContacts();
    gCombinedInputContacts = initCombinedInputContacts();
    gStandaloneInputContacts = initStandaloneInputContacts();

    // Asynchronously get the control interfaces.
    // getAppControlInterfaces() is an application method returning
    // remote control interfaces or a local control interfaces depending
    // whether the code is running on a PC or on the video player.
    // It is calling IDAL.getControlInterfaces() or IDAL.getRemoteControlInterfaces().
    getAppControlInterfaces().then(onControlInterfaceAvailable);
}

function initOutputContacts() {
    var contacts = [];
    var parent = document.getElementById("output-container");
    for (var i = 0 ; i < 8 ; i++) {
        contacts.push(createOutputContactCheckBox(parent, i));
    }
    return contacts;
}

function initCombinedInputContacts() {
    var contacts = [];
    var parent = document.getElementById("combined-input-container");
    for (var i = 0 ; i < 8 ; i++) {
        contacts.push(createInputContactCheckBox(parent, i));
    }
    return contacts;
}

function initStandaloneInputContacts() {
    var contacts = [];
    var parent = document.getElementById("standalone-input-container");
    contacts.push(createInputContactCheckBox(parent, 0));
    return contacts;
}

function setOutputById(id, value) {
    if (gContactControlInterface !== undefined) {
        gContactControlInterface.setOutputById(id, value)
            .then(function(result) {
                gConsole.log("Contact.setOutputById(" + JSON.stringify(id) + ", " + JSON.stringify(value) + ") => " + JSON.stringify(result));
            })
            .catch(function(error) {
                gConsole.error("Error: Contact.setOutputById(" + JSON.stringify(id) + ", " + JSON.stringify(value) + ") => " + JSON.stringify(error));
            });
    }
}

function setOutputByMask(value, mask) {
    if (gContactControlInterface !== undefined) {
        gContactControlInterface.setOutputByMask(value, mask)
            .then(function(result) {
                gConsole.log("Contact.setOutputByMask(" + value + ", " + mask + ") => " + JSON.stringify(result));
            })
            .catch(function(error) {
                gConsole.error("Error: Contact.setOutputByMask(" + value + ", " + mask + ") => " + JSON.stringify(error));
            });
    }
}

function setAllCheckBoxes(value) {
    var checkboxes = gOutputContacts;
    if (checkboxes !== undefined) {
        for (var i = 0 ; i < checkboxes.length ; i++) {
            checkboxes[i].checked = value;
        }
    }
}

function onControlInterfaceAvailable(iface) {
    gConsole.log("Control interface available");

    gContactControlInterface = iface.contact;

    // Disable default input contact management.
    // Input contacts will be managed by this app.
    var config = {
        controller: "browser",
        lifetime: "url"
    };

    gConsole.log("Let this app handle input contact (disable default management)");
    gContactControlInterface.setInputConfiguration(config)
        .then(function(e) {
            gConsole.log("Contact.setInputConfiguration(" + JSON.stringify(config) + ") => " + JSON.stringify(e));
        })
        .catch(function(e) {
            gConsole.error("Error: Contact.setInputConfiguration(" + JSON.stringify(config) + ") => " + JSON.stringify(e));
        });

    // Process input contact events
    gContactControlInterface.addListener(function(e) {
        var detail = e.detail;
        var checkboxes;

        gConsole.log("Event 'idal-contact-event': " + JSON.stringify(detail));

        if (detail.type == "input-change" || !detail.type) {
            switch (detail.name) {
                case "combined":
                    checkboxes = gCombinedInputContacts;
                    break;

                case "standalone":
                    checkboxes = gStandaloneInputContacts;
                    break;
            }

            setCheckboxesStates(checkboxes, e.detail);
        }
    });

    // Get initial input contact state
    setInitialInputStates("combined", gCombinedInputContacts);
    setInitialInputStates("standalone", gStandaloneInputContacts);
}

function setInitialInputStates(name, checkboxes) {
    gConsole.log("Set initial input contact values for " + name);
    gContactControlInterface.getInputByName(name)
        .then(function(info) {
            gConsole.log("Contact.getInputByName(" + JSON.stringify(name) + ") => " + JSON.stringify(info));
            setCheckboxesStates(checkboxes, info);
        })
        .catch(function(error) {
            gConsole.error("Error: Contact.getInputByName(" + JSON.stringify(name) + ") => " + JSON.stringify(error));
        });
}

function setCheckboxesStates(checkboxes, info) {
    if (checkboxes) {
        for (var i = 0 ; i < info.values.length ; i++) {
            var checkbox = checkboxes[i];
            if (checkbox) {
                checkbox.checked = info.values[i];
            }
        }
    }
}

window.addEventListener("load", onPageLoaded);
